@@ -9,6 +9,8 @@
  *                                                                         *
  ***************************************************************************/
 
+#include <QApplication>
+#include <QPixmap>
 #include "addtagdialog.h"
 
 
@@ -17,6 +19,26 @@ AddTagDialog::AddTagDialog(QWidget *parent)
 {
 setModal(true);
 ui.setupUi(this);
+QPixmap pixmap1, pixmap2;
+#if (QT_VERSION >= QT_VERSION_CHECK(5, 0, 0))
+if (qApp->devicePixelRatio()==2)
+  {
+  pixmap1.load(":/images/trigger@2x.png");
+  pixmap1.setDevicePixelRatio(qApp->devicePixelRatio());
+  pixmap2.load(":/images/triggerbis@2x.png");
+  pixmap2.setDevicePixelRatio(qApp->devicePixelRatio());
+  }
+else 
+  {
+  pixmap1.load(":/images/trigger.png");
+  pixmap2.load(":/images/triggerbis.png");
+  }
+#else
+  pixmap1.load(":/images/trigger.png");
+  pixmap2.load(":/images/triggerbis.png");
+#endif
+ui.label_4->setPixmap(pixmap1);
+ui.label_5->setPixmap(pixmap2);
 }
 AddTagDialog::~AddTagDialog()
 {
