@@ -1,6 +1,6 @@
 /***************************************************************************
- *   copyright            : (C) 2003 by Pascal Brachet                     *
- *                                                                         *
+ *   copyright       : (C) 2003-2009 by Pascal Brachet                     *
+ *   http://www.xm1math.net/texmaker/                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -11,24 +11,15 @@
 
 #ifndef REFDIALOG_H
 #define REFDIALOG_H
-#include <qlayout.h>
-#include <qcombobox.h>
-#include <qpushbutton.h>
-#include <qdialog.h>
-/**
-  *@author Pascal Brachet
-  */
 
-class refdialog : public QDialog  {
+#include "ui_refdialog.h"
+
+class RefDialog : public QDialog  {
    Q_OBJECT
 public:
-	refdialog(QWidget *parent=0, const char *name=0);
-	~refdialog();
-
-public:
-  QComboBox *combo1;
-	QPushButton *buttonOk;
-	QPushButton *buttonCancel;
+	RefDialog(QWidget *parent=0, const char *name=0);
+	~RefDialog();
+	Ui::RefDialog ui;
 };
 
 
